#
# K2HDKC
# 
# Copyright 2016 Yahoo Japan Corporation.
# 
# K2HDKC is k2hash based distributed KVS cluster.
# K2HDKC uses K2HASH, CHMPX, FULLOCK libraries. K2HDKC supports
# distributed KVS cluster server program and client libraries.
# 
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Thu Mar 31 2016
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.15

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: k2hash based distributed KVS cluster.
Name: k2hdkc
Version: 1.0.15
Release: %{package_revision}%{?dist}
License: MIT
Group: Applications/Databases
URL: https://github.com/yahoojapan/k2hdkc
Source0: https://github.com/yahoojapan/k2hdkc/archive/%{gittag}/%{name}-%{version}.tar.gz
Requires: libfullock%{?_isa} >= 1.0.62, k2hash%{?_isa} >= 1.0.98, chmpx%{?_isa} >= 1.0.108
BuildRequires: systemd git-core gcc-c++ make libtool libfullock-devel >= 1.0.62, k2hash-devel >= 1.0.98, chmpx-devel >= 1.0.108, libyaml-devel

%description
k2hdkc is k2hash based distributed KVS cluster server program and
client libraries.
k2hdkc is build with k2hash and chmpx libraries. k2hdkc creates cluster
which includes many server nodes, and is accessed from slave node. The
k2hdkc cluster is dispersed by consistent hashing and are automatically
laid out. As a result, it provides a high performance, a high scalabil-
ity KVS.

k2hdkc is following specifications:
- Distributed KVS based by k2hash and chmpx
- Three type data type(on memory/full mapped file/mapped index in
file)
- Keys have subkeys
- Supports Queue(and Keyed Queue)
- Supports compare and swap function
- Auto scaled in cluster
- Data merging automatically
- Programmable addin(transaction plugin)
- Build up multi cluster

%prep
%autosetup -n %{name}-%{version}

%build
%run_autogen
%configure --disable-static 
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
install -D -m 644 buildutils/k2hdkc.service %{buildroot}/lib/systemd/system/k2hdkc.service
install -D -m 755 buildutils/k2hdkc-service-helper %{buildroot}/usr/libexec/k2hdkc-service-helper
install -D -m 644 buildutils/k2hdkc-service-helper.conf %{buildroot}/etc/antpickax/k2hdkc-service-helper.conf
install -D -m 644 buildutils/k2hdkc.ini.example %{buildroot}/etc/antpickax/k2hdkc.ini.example
install -D -m 644 buildutils/override.conf.k2hdkc_example %{buildroot}/etc/antpickax/override.conf.k2hdkc_example

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%files

%license COPYING

%doc README AUTHORS ChangeLog
%{_libdir}/*.so.*
%{_mandir}/man1/*
%{_bindir}/*
/lib/systemd/system/k2hdkc.service
/usr/libexec/k2hdkc-service-helper
/etc/antpickax/*

%preun
%systemd_preun k2hdkc.service

#
# devel package
#
%package devel
Summary: k2hash based distributed KVS cluster. (development)
Requires: %{name}%{?_isa} = %{version}-%{release}, libfullock-devel%{?_isa} >= 1.0.62, k2hash-devel%{?_isa} >= 1.0.98, chmpx-devel%{?_isa} >= 1.0.108, libyaml-devel

%description devel
Development package for building with k2hdkc shared library.
This package has header files and symbols for it.

%files devel

%doc README AUTHORS ChangeLog
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Feb 07 2025 Takeshi Nakatani <ggtakec@gmail.com> 1.0.15-1
- Changed support OSes and Fixed scripts, etc - #93

* Fri Nov 29 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.14
- Updated K2HFILE virables value in example - #90

* Wed Nov 13 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.13
- Changed supported OS and modified some codes - #88

* Mon Mar 11 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.12
- Changed support OS and Fixed about cppcheck, etc - #86

* Fri Nov 17 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.11
- Updated build_helper.sh for fixing a bug and installing ruby - #84

* Mon Oct 30 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.10
- Changed support OS (fedora and ubuntu) and updated tool - #82

* Mon Oct 02 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.9
- Updated versions of dependent packages - #80

* Thu Aug 31 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.8
- Updated tool scripts and support OSs - #78
- Fixed bugs about test scripts - #77
- Fixed .gitignore to exclude APKBUILD.templ - #76

* Wed Jul 19 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.7
- Fixed a bug in script for systemd - #74

* Mon May 15 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.6
- Updated versions of dependent packages - #72

* Wed Mar 01 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.5
- Updated building/packaging logic for ALPINE - #70

* Fri Feb 10 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.4
- Changed CI process flow/OSs and added Alpine OS - #68
- Updated header and footer in comment lines - #67
- Updated issue/pullrequest templates - #65
- Removed unnecessary unmatchedSuppression comment - #64
- Added ShellCheck processing and reviewed cppcheck - #63
- Eliminated unnecessary copies in build_helper.sh - #62
- Updated docker/login-action from v1 to v2 - #61
- Shared Docker image build logic with other products - #60
- Updated github actions process and support os, and fixed bugs - #59
- Updated scripts for adding grep params and replacing which to command - #58
- Updated common build scripts - #57
- Updated Antpickax common scripts and tools under the buildutils directory - #56
- Fixed errors reported by cppcheck 2.9 - #55
- Enabled external customization of configure.ac and fixed for building - #54

* Mon Sep 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.3
- Bumpup for updating the base Docker image because of k2htpdtor updated

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.2
- Fixed Dockerfile template for calling ldconfig - #51

* Wed Aug 18 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.1
- Added docker build and push in Github Actions - #49
- Functional improvements and bug fixes - #48

* Fri Mar 26 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.0
- Updated README.md for a reference to k2hdkc dbaas - #46

* Mon Mar 15 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.37
- Fixed to check and create k2hash data directory - #44

* Fri Feb 05 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.36
- Fixed a bug in k2hdk-service-helper - #42

* Thu Feb 04 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.35
- Fixed an issue with stopping service subprocesses - #40
- Bypass a specific version of cppcheck due to poor performance - #39

* Wed Feb 03 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.34
- Enhanced confirmation of wait process for k2hdkc.service - #37

* Wed Jan 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 0.9.33
- Updated files for systemd service - #34

* Thu Dec 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 0.9.32
- Added systemd service files to package - #30
- Fixed centos8 build and removed centos6 build - #29

* Tue Nov 17 2020 Takeshi Nakatani <ggtakec@gmail.com> 0.9.31
- Switched Travis CI to Github actions and extended supported OS - #27
- Fixed bugs detected by cppcheck - #26

* Thu Apr 09 2020 Takeshi Nakatani <ggtakec@gmail.com> 0.9.30
- Fixed a bug that replication of key deletion was not performed - #24
- Fixed dead loop in removing key with looping subkey - #23
- Fixed code for cppcheck 1.90 - #22

* Thu Dec 26 2019 Takeshi Nakatani <ggtakec@gmail.com> 0.9.29
- Updated dependencies and codes with CHMPX code update - #18

* Fri Mar 15 2019 Takeshi Nakatani <ggtakec@gmail.com> 0.9.28
- Fixed codes for cppcheck 1.87 - #15

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 0.9.27
- Fixed misspelling, and etc - #12
- Added check using cppcheck - #11
- Reflected the spelling check result for all sources - #10

* Mon Dec 10 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.26
- Changed to strict packaging and changed documents

* Mon Nov 12 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.25
- Fixed a bug about initializing debug class

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.24
- Fixed spec file and updated dependency

* Mon Aug 13 2018 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 0.9.23
- Wrong arguments in k2hdkc_pm_remove_str_subkey functions

* Mon Jul 02 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.22
- avoid static object initialization order problem(SIOF)

* Thu May 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.21
- Cleanup credit comments in sources and Modified etc
- Changed build logic to new for rpm/debian packaging
- Fixed filename typo from make_valiables.sh to make_variables.sh

* Tue Mar 27 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.20
- Update dependency on k2hash and chmpx

* Mon Feb 26 2018 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 0.9.19
- Bump up version with nothing update

* Wed Feb 21 2018 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 0.9.18
- Bump up version with nothing update

* Mon Feb 19 2018 Hirotaka Wakabayashi <hiwakaba@yahoo-corp.jp> 0.9.17
- Fixed C++ statements mixed in lib/k2hdkccomstructure.h

* Wed Feb 14 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.16
- Fixed C++ statements mix in including k2hdkc.h
- update readme

* Thu Feb 01 2018 Takeshi Nakatani <ggtakec@gmail.com> 0.9.15
- First version of open sorce on Github
